==> libreoffice-fresh-sdk-24.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.js <==
var servicecom_1_1sun_1_1star_1_1chart2_1_1Axis =
[
    [ "PropertySet", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a7d5a91c8e6efda15ec633d49592489c2", null ],
    [ "LineProperties", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a360075bd97e5a4787d283a473b073005", null ],
    [ "CharacterProperties", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#aa3a0375877da5f1f9dd231c0319b9b13", null ],
    [ "CharacterPropertiesAsian", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ad300afa727567658d7fe69920f186249", null ],
    [ "CharacterPropertiesComplex", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a81d39b8bf45f5353c1bacece803eca76", null ],
    [ "XAxis", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ae7e7c3cf65e747bdb4dbf965152949cb", null ],
    [ "XTitled", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ae3e019c7ed62e495202a149b04a20302", null ],
    [ "ArrangeOrder", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a37e0f215ae3bd9e3f55e28672245bea6", null ],
    [ "BuiltInUnit", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a5070406dbfe5c6f59e3633577b0b090c", null ],
    [ "CrossoverPosition", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a1b28f98780fef2517386262cf998107b", null ],
    [ "CrossoverValue", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a536859a657fb574539dc3d6fa0e84dca", null ],
    [ "DisplayLabels", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ab2629499219d2d216bc07402404cdff6", null ],
    [ "DisplayUnits", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a408b5744a4a5377632b19304a9ebfdb2", null ],
    [ "LabelPosition", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a20542103398ff69d493a06106850aa1c", null ],
    [ "MajorOrigin", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a8a488dcd72b60bfcb65695ee2a7ac095", null ],
    [ "MajorTickmarks", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a66acd0c984bcdc06136796a3b2aa35b8", null ],
    [ "MarkPosition", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#adb7290c53240084e62bc83f66a0577be", null ],
    [ "MinorTickmarks", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a4bfb583979441a9b9503d228135feac8", null ],
    [ "NumberFormat", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a47bcb1c1fb4b08615d0866e989fd6f87", null ],
    [ "ReferencePageSize", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a3b2eb5f3b79489d9787e2f9578d06bb7", null ],
    [ "Show", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a39dcb2e507d4d565339bbf2892bd3a42", null ],
    [ "StackCharacters", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a895a0c2acd2f265b8cda3a8df22ac434", null ],
    [ "TextBreak", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a5058b60acd9098f8d62270c1e363a3c9", null ],
    [ "TextOverlap", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ab6c3489ebb54d2b1519241387dcebb35", null ],
    [ "TextRotation", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a1564f219a6033b2ee5afda5b29f00aa7", null ],
    [ "TryStaggeringFirst", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a1817a3a283964b114c111b5dd9e087cd", null ]
];

==> libreoffice-fresh-sdk-25.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.js <==
var servicecom_1_1sun_1_1star_1_1chart2_1_1Axis =
[
    [ "::com::sun::star::beans::PropertySet", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a7d5a91c8e6efda15ec633d49592489c2", null ],
    [ "::com::sun::star::drawing::LineProperties", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a360075bd97e5a4787d283a473b073005", null ],
    [ "::com::sun::star::style::CharacterProperties", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#aa3a0375877da5f1f9dd231c0319b9b13", null ],
    [ "::com::sun::star::style::CharacterPropertiesAsian", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ad300afa727567658d7fe69920f186249", null ],
    [ "::com::sun::star::style::CharacterPropertiesComplex", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a81d39b8bf45f5353c1bacece803eca76", null ],
    [ "::com::sun::star::chart2::XAxis", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ae7e7c3cf65e747bdb4dbf965152949cb", null ],
    [ "::com::sun::star::chart2::XTitled", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ae3e019c7ed62e495202a149b04a20302", null ],
    [ "ArrangeOrder", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a37e0f215ae3bd9e3f55e28672245bea6", null ],
    [ "BuiltInUnit", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a5070406dbfe5c6f59e3633577b0b090c", null ],
    [ "CrossoverPosition", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a1b28f98780fef2517386262cf998107b", null ],
    [ "CrossoverValue", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a536859a657fb574539dc3d6fa0e84dca", null ],
    [ "DisplayLabels", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ab2629499219d2d216bc07402404cdff6", null ],
    [ "DisplayUnits", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a408b5744a4a5377632b19304a9ebfdb2", null ],
    [ "LabelPosition", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a20542103398ff69d493a06106850aa1c", null ],
    [ "MajorOrigin", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a8a488dcd72b60bfcb65695ee2a7ac095", null ],
    [ "MajorTickmarks", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a66acd0c984bcdc06136796a3b2aa35b8", null ],
    [ "MarkPosition", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#adb7290c53240084e62bc83f66a0577be", null ],
    [ "MinorTickmarks", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a4bfb583979441a9b9503d228135feac8", null ],
    [ "NumberFormat", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a47bcb1c1fb4b08615d0866e989fd6f87", null ],
    [ "ReferencePageSize", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a3b2eb5f3b79489d9787e2f9578d06bb7", null ],
    [ "Show", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a39dcb2e507d4d565339bbf2892bd3a42", null ],
    [ "StackCharacters", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a895a0c2acd2f265b8cda3a8df22ac434", null ],
    [ "TextBreak", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a5058b60acd9098f8d62270c1e363a3c9", null ],
    [ "TextOverlap", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#ab6c3489ebb54d2b1519241387dcebb35", null ],
    [ "TextRotation", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a1564f219a6033b2ee5afda5b29f00aa7", null ],
    [ "TryStaggeringFirst", "servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html#a1817a3a283964b114c111b5dd9e087cd", null ]
];
